@@ -99,16 +99,7 @@ cd $catchupdir
 channel=$1
 if [ "$1" == "" ]
 	then
-	echo " 1 BBC One         2 BBC Two       3 ITV1"
-	echo " 4 Channel 4       5 FIVE          6 ITV2"
-	echo " 7 Five USA        8 E4            9 ITV3"
-	echo "10 ITV4           11 More 4       12 BBC Three"
-	echo "13 BBC Four       15 Fiver        16 Film 4"
-	echo "17 BBC News       18 CBBC         19 CITV"
-	echo "20 Channel 4 +1   21 E4 +1        23 ITV2 +1"
-	echo "24 CBeebies       25 4Music       27 More4 +1"
-	echo "28 ITV3 +1        29 ITV4 +1      30 Film4 +1"
-	echo "31 BBC Parliament"
+	cat /opt/tvcplayer/channels
 	echo Select channel:
 	read channel
 fi
